<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nk="http://netkernel.org" xmlns:xrl="http://netkernel.org/xrl">
    <xsl:output method="xml" omit-xml-declaration="yes"/>
    
	<xsl:param name="doclist"/>
	<xsl:param name="docid" nk:class="java.lang.String"/>
	<xsl:param name="bookid" nk:class="java.lang.String"/>
	
	<xsl:variable name="docs" select="$doclist//doc"/>

	<xsl:key name="items" match="//item" use="@id"/>
	
	<xsl:template match="/book">
	<span>
		<xsl:variable name="current" select="key('items',$docid)" />
		<xsl:variable name="prev1" select="$current/preceding-sibling::*[1]" />
		<xsl:variable name="prev2" select="$current/parent::item" />

		<span>
		<a href="/tools/docmap/" class="iconlink">
			<span class="icon-asterisk large-icon-link" style="text-decoration: none;"> 
				</span>
		</a>
		</span>

		<span>
		<xsl:choose>
			<xsl:when test="$prev1">
				<xsl:call-template name="previous">
					<xsl:with-param name="item" select="$prev1" />
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$prev2">
				<xsl:call-template name="previous">
					<xsl:with-param name="item" select="$prev2" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<span class="icon-circle-arrow-left large-icon-link" style="color: #aaaaaa;"> 
				</span>
			</xsl:otherwise>
		</xsl:choose>
		</span>
		<span>
		<xsl:variable name="next1" select="$current/child::item[1]" />
		<xsl:variable name="next2" select="$current/following::item[1]" />
		<xsl:choose>
			<xsl:when test="$next1">
				<xsl:call-template name="next">
					<xsl:with-param name="item" select="$next1" />
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$next2">
				<xsl:call-template name="next">
					<xsl:with-param name="item" select="$next2" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<span class="icon-circle-arrow-right large-icon-link" style="color: #aaaaaa;"> 
				</span>
			</xsl:otherwise>
		</xsl:choose>
		</span>
	</span>

</xsl:template>
	
	<xsl:template name="next">
		<xsl:param name="item"/>
			<a href="/book/view/{$bookid}/{$item/@id}" class="iconlink">
				<xsl:attribute name="title">
					<xsl:value-of select="desc"/>
				</xsl:attribute>
				<span class="icon-circle-arrow-right large-icon-link book-navbar-spacer" style="text-decoration: none;"> 
					<xsl:attribute name="title">Next : <xsl:value-of select="$docs[id=$item/@id]/title"/></xsl:attribute>
				</span>
			</a>
	</xsl:template>
	
	<xsl:template name="previous">
		<xsl:param name="item"/>
			<a href="/book/view/{$bookid}/{$item/@id}" class="iconlink">
				<span class="icon-circle-arrow-left large-icon-link" style="text-decoration: none;"> 
					<xsl:attribute name="title">Previous : <xsl:value-of select="$docs[id=$item/@id]/title"/></xsl:attribute>
				</span>
			</a>
	</xsl:template>
	
</xsl:stylesheet>
