package org.netkernel.doc.endpoint;

import java.util.Map;

import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.representation.IHDSNodeList;
import org.netkernel.layer0.representation.impl.HDSBuilder;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;

public class DocSearchIndexEndpoint extends StandardAccessorImpl
{
	public DocSearchIndexEndpoint()
	{	this.declareThreadSafe();
	}

	@Override
	public void onSource(INKFRequestContext context) throws Exception
	{	
		Map<String,String> map1=context.source("active:documentBookMap",Map.class);
		Map<String,IHDSNode> map2=context.source("active:bookMap",Map.class);
		//System.out.println(map);
		//id=context.getThisRequest().getArgumentValue("id");
		//book=map.get(id);	
		
		HDSBuilder b=new HDSBuilder();
		IHDSNode tree=context.source( "active:documentationTree", IHDSNode.class);
		IHDSNodeList nl=tree.getNodes("//doc");
		for(int i=0; i<nl.size(); i++)
		{	IHDSNode doc=nl.get(i);
			String id=(String)doc.getFirstValue("id");
			
			if (doc.getFirstNode("noindex")!=null)
			{	continue;
			}
			
			String bookTitle=null;
			try
			{
			String bookId=map1.get(id);
			IHDSNode book=map2.get(bookId);
			bookTitle = (String)book.getFirstValue("book/title");
			//System.out.println(id+" -> "+bookTitle);
			}
			catch (Exception e)
			{
			}
			String docSrc="res:/doc/source/"+id;
			
			
			b.pushNode("item");
				b.pushNode("field");
					b.addNode("name", "default");
					b.addNode("uri", docSrc);
				b.popNode();
					b.pushNode("field");
					b.addNode("@index", "NO");
					b.addNode("@store", "YES");
					b.addNode("name", "resolverID");
					b.addNode("value", "searchDocResolver");
				b.popNode();
				
				b.pushNode("field");
					b.addNode("@index", "NO");
					b.addNode("@store", "YES");
					b.addNode("name", "documentID");
					b.addNode("value", id);
				b.popNode();
				String s=(String)doc.getFirstValue("title");
				if(s!=null && s.length()>0)
				{	b.pushNode("field");
						b.addNode("@index", "ANALYZED");
						b.addNode("@store", "YES");
						b.addNode("name", "title");
						b.addNode("value", s);
					b.popNode();
					if (bookTitle!=null)
					{
						b.pushNode("field");
						b.addNode("@index", "NO");
						b.addNode("@store", "YES");
						b.addNode("name", "dtitle");
						b.addNode("value", bookTitle+" / "+s);
						b.popNode();
					}
				}
				s=(String)doc.getFirstValue("desc");
				if(s!=null && s.length()>0)
				{	b.pushNode("field");
						b.addNode("@index", "ANALYZED");
						b.addNode("@store", "YES");
						b.addNode("name", "desc");
						b.addNode("value", s);
					b.popNode();
				}
				s=(String)doc.getFirstValue("keywords");
				if(s!=null && s.length()>0)
				{	b.pushNode("field");
						b.addNode("@index", "ANALYZED");
						b.addNode("@store", "NO");
						b.addNode("name", "keywords");
						b.addNode("value", s);
					b.popNode();
				}
				s=(String)doc.getFirstValue("category");
				if(s==null || s.length()==0)
				{	s="doc";
				}
				b.pushNode("field");
					b.addNode("@index", "ANALYZED");
					b.addNode("@store", "YES");
					b.addNode("name", "category");
					b.addNode("value", s);
				b.popNode();
			
			//index reference docs
			String docTxt=context.source(docSrc,String.class);
			int i1=docTxt.indexOf("{endpoint}");
			if (i1>=0)
			{	int i2=docTxt.indexOf("{/endpoint}",i1);
				if (i2>=0)
				{	String eid=docTxt.substring(i1+10,i2);
					b.pushNode("field");
					b.addNode("@index", "NOT_ANALYZED");
					b.addNode("@store", "NO");
					b.addNode("name", "eid");
					b.addNode("value", eid);
					b.popNode();
				}
			}
			
			b.popNode();
			
		}
		
		
		context.createResponseFrom(b.getRoot());
	}
	
	
}
